# !/usr/bin/env python
# _*_coding: utf-8 _*_
# @Time: 2020/2/29 18:02
# @Author: "John"
import json


def beautiful_output_dict(d, encoding='utf-8', indent=4, sort_keys=True, ensure_ascii=False):
    """
        将 Python 的字典， 以展开的方式输出
    :param d: 要处理的字典
    :param encoding: 编码方式，默认 utf-8
    :param indent:  缩进
    :param sort_keys: 根据字典的 key 进行排序
    :param ensure_ascii:
    :return:
    """
    return json.dumps(json.loads(d, encoding=encoding), sort_keys=sort_keys, indent=indent, ensure_ascii=ensure_ascii)



# !/usr/bin/env python
# _*_coding: utf-8 _*_
# @Time: 2019\10\8 0008 23:45
# @Author: "John"


def get_sorted_un_duplicated_list(li):
    """
        将给定的 list 进行去重，并按照原来的顺序返回
    :param li:
    :return:
    """
    if len(li):
        rest = []
        temp_set = set()
        for item in li:
            temp_set_size_bf = len(temp_set)
            temp_set.add(item)
            temp_set_size_aft = len(temp_set)
            # set size 有变化，说明该 item 不在 set 中；
            if temp_set_size_aft > temp_set_size_bf:
                rest.append(item)
            else:
                # 打印重复的那个
                # print(item)
                pass
        return rest



# !/usr/bin/env python
# _*_coding: utf-8 _*_
# @Time: 2019/10/9 9:53
# @Author: "John"
import base64
import json

import requests
import urllib3

urllib3.disable_warnings()


def send_msg_2_queue(msg, queue_name, service_address):
    """

    :param msg: 消息内容，需要 String 或者 json.dumps(object)
    :param queue_name:
    :param service_address:
    :return:
    """
    data = {
        "message": base64.b64encode(msg.encode('utf-8')).decode("utf-8"),
        "queueName": queue_name,
        "priority": 8,
        "delaySeconds": ""
    }

    headers = {"Content-type": "application/json; charset=UTF-8", "Accept": "application/json"}

    response = requests.post(service_address, headers=headers, data=json.dumps(data).encode('utf-8'))
    if not json.loads(response.text).get("error_code"):
        return 1



# !/usr/bin/env python
# _*_coding: utf-8 _*_
# @Time: 2019/11/14 15:08
# @Author: "John"
import json
import uuid

import requests
import urllib3

urllib3.disable_warnings()


def sync_open_search(pid, db, collection, service_address, topic='TweOpensearch', is_sandbox=True):
    """

    :param pid:
    :param db:
    :param collection:
    :param service_address:
    :param topic: default for TweOpensearch
    :param is_sandbox: default for sandbox，not sync openSearch
    :return:
    """
    if is_sandbox:
        print(f"It is a test, not sync openSearch: pid:{pid}。")
        return

    headers = {"Content-type": "application/json; charset=UTF-8", "Accept": "application/json"}

    msg = {
        "topic": topic,
        "traceID": str(uuid.uuid1()).replace('-', ''),
        "msgData": {
            "mongodb": db,
            "collection": collection,
            "primaryKey": "PID",
            "primaryValue": pid.strip(),
            "isNew": 0
        }
    }

    resp = requests.post(service_address, headers=headers, data=json.dumps(msg))
    if resp.json().get("success"):
        return 1
